package cqo1;

/*
   Copyright: Copyright (c) 1998-2007 MOSEK ApS, Denmark. All rights reserved.

   File:      cqo1.java

   Purpose:   Demonstrates how to solve a small conic qaudratic
              optimization problem using the MOSEK API.
*/

import mosek.*;
 
class msgclass extends mosek.Stream {
    public msgclass ()
    {
        super ();
    }

    public void print (String msg)
    {
        System.out.print (msg);
    }
}
  
public class cqo1
{
    static final int NUMCON = 1;
    static final int NUMVAR = 6;
    static final int NUMANZ = 4;

    public static void main (String[] args)
    {
        // Since the value infinity is never used, we define
        // 'infinity' symbolic purposes only
        double infinity = 0;
         
        int[] bkc    = { mosek.Env.boundkey.fx };
        double[] blc = { 1.0 };
        double[] buc = { 1.0 };
        
        int bkx[] = {mosek.Env.boundkey.lo,
                     mosek.Env.boundkey.lo,
                     mosek.Env.boundkey.lo,
                     mosek.Env.boundkey.lo,
                     mosek.Env.boundkey.fr,
                     mosek.Env.boundkey.fr};
        double[] blx = { 0.0,
                         0.0,
                         0.0,
                         0.0,
                         -infinity,
                         -infinity};
        double[] bux = { 0.0,
                         0.0,
                         0.0,
                         0.0,
                         +infinity,
                         +infinity};
        
        double[] c   = { 0.0,
                         0.0,
                         0.0,
                         0.0,
                         1.0,
                         1.0};
        
        double[] aval   = {1.0,
                           1.0,
                           1.0,
                           1.0};
        int[]    asub   = {0,
                           0,
                           0,
                           0};
        int[] ptrb = {0,1,2,3,5,5};
        int[] ptre = {1,2,3,4,5,5};
        
        int[] csub = new int[3];
        double[] xx  = new double[NUMVAR];
        mosek.Env
            env = null;
        mosek.Task
            task = null;

        // create a new environment object
        env  = new mosek.Env ();
        try
            {
                // if you like, do some pre-initialization here
                // (e.g. setting up exit or stream callback)
                // then initialize the environment for use
                env.init ();
                // create a task object attached to the environment
                task = new mosek.Task (env, NUMCON, NUMVAR);
                msgclass msgobj = new msgclass ();

                task.inputdata(NUMCON,NUMVAR,
                               c,
                               0.0,
                               ptrb,
                               ptre,
                               asub,
                               aval,
                               bkc,
                               blc,
                               buc,
                               bkx,
                               blx,
                               bux);
                csub[0] = 4;
                csub[1] = 0;
                csub[2] = 2;
//REF:func:task:appendcone
//REF:enum:conetype:quad
                task.appendcone(mosek.Env.conetype.quad,
                                0.0, /* For future use only, can be set to 0.0 */
                                csub);
                csub[0] = 5;
                csub[1] = 1;
                csub[2] = 3;
//REF:enum:conetype:rquad
                task.appendcone(mosek.Env.conetype.quad,0.0,csub);

                System.out.println ("putintparam");
                task.putobjsense(mosek.Env.objsense.min);

                System.out.println ("optimize");
                try
                    {
                        task.optimize();
                    }
                catch (mosek.Warning e)
                    {
                        System.out.println ("Mosek warning:");
                        System.out.println (e.toString ());
                    }

                System.out.println ("solutionsummary");
                task.solutionsummary(mosek.Env.streamtype.msg);

                System.out.println ("getsolutionslice");
                task.getsolutionslice(mosek.Env.soltype.itr,
                                      /* Interior solution. */
                                      mosek.Env.solitem.xx,
                                      /* Which part of solution. */
                                      0,
                                      /* Index of first variable. */
                                      NUMVAR,
                                      /* Index of last variable+1 */
                                      xx);
                for(int j = 0; j < NUMVAR; ++j)
                    System.out.println ("x[" + j + "]:" + xx[j]);
            }
        catch (mosek.ArrayLengthException e)
            /* Catch both Error and Warning */
            {
                System.out.println ("Error: An array was too short");
                System.out.println (e.toString ());
            }
        catch (mosek.Exception e)
            /* Catch both Error and Warning */
            {
                System.out.println ("An error was encountered");
                System.out.println (e.getMessage ());
            }

        if (task != null) task.dispose ();
        if (env  != null)  env.dispose ();
    }
}
