package lo2;

/*
   Copyright: Copyright (c) 1998-2007 MOSEK ApS, Denmark. All rights reserved.

   File:      lo2.java

   Purpose:   Demonstrates how to solve a small linear
              optimization problem using the MOSEK Java API.
*/

import mosek.*;

class msgclass extends mosek.Stream {
    public msgclass ()
    {
        super ();
    }

    public void print (String msg)
    {
        System.out.print (msg);
    }
}
 
public class lo2
{
    static final int NUMCON = 3;
    static final int NUMVAR = 4;
    static final int NUMANZ = 9;

    public static void main (String[] args)
    {

        // Since the value infinity is never used, we define
        // 'infinity' symbolic purposes only
        double
            infinity = 0;
  
        double c[]    = {3.0, 1.0, 5.0, 1.0};
        int    asub[][] = { {0, 1},
                            {0, 1, 2},
                            {0, 1},
                            {1, 2} };
        double aval[][] = { {3.0, 2.0},
                            {1.0, 1.0, 2.0},
                            {2.0, 3.0},
                            {1.0, 3.0} };
      
        int     bkc[]  = {mosek.Env.boundkey.fx,
                          mosek.Env.boundkey.lo,
                          mosek.Env.boundkey.up};
        double  blc[]  = {30.0,
                          15.0,
                          -infinity};
        double  buc[]  = {30.0,
                          +infinity,
                          25.0};
        
        int     bkx[]  = {mosek.Env.boundkey.lo,
                          mosek.Env.boundkey.ra,
                          mosek.Env.boundkey.lo,
                          mosek.Env.boundkey.lo};
        double  blx[]  = {0.0,
                          0.0,
                          0.0,
                          0.0};
        double  bux[]  = {+infinity,
                          10.0,
                          +infinity,
                          +infinity};
       
        double[] xx  = new double[NUMVAR];

        mosek.Env
            env = null;
        mosek.Task
            task = null;
        
        try
            {
                // Make mosek environment. 
                env  = new mosek.Env ();
                // Initialize the environment.
                env.init ();
                // Create a task object linked with the environment env.
                task = new mosek.Task (env, NUMCON, NUMVAR);
              
                /* Give MOSEK an estimate on the size of
                   the data to input. This is done to increase
                   the speed of inputing data and is optional.*/
                
                task.putmaxnumvar(NUMVAR);
                task.putmaxnumcon(NUMCON);
                task.putmaxnumanz(NUMANZ);
                                    
                /* Append the constraints. */
                task.append(mosek.Env.accmode.con,NUMCON);

                /* Append the variables. */
                task.append(mosek.Env.accmode.var,NUMVAR);

                /* Put C. */
                task.putcfix(0.0);
                for(int j=0; j<NUMVAR; ++j)
                  task.putcj(j,c[j]);

                /* Put constraint bounds. */
                for(int i=0; i<NUMCON; ++i)
                  task.putbound(mosek.Env.accmode.con,i,bkc[i],blc[i],buc[i]);

                /* Put variable bounds. */
                for(int j=0; j<NUMVAR; ++j)
                  task.putbound(mosek.Env.accmode.var,j,bkx[j],blx[j],bux[j]);

                /* Put A. */
                if ( NUMCON>0 )
                {
                  for(int j=0; j<NUMVAR; ++j)
                    task.putavec(mosek.Env.accmode.var,
                                 j,
                                 asub[j],
                                 aval[j]);
                }

                /* A maximization problem */ 
                task.putobjsense(mosek.Env.objsense.maximize);

                /* Solve the problem */
                try
                    {
                        task.optimize();
                    }
                catch (mosek.Warning e)
                    {
                        System.out.println ("Mosek warning:");
                        System.out.println (e.toString ());
                    }

                task.solutionsummary(mosek.Env.streamtype.msg);

                task.getsolutionslice(mosek.Env.soltype.bas,
                                      /* Basic solution.       */
                                      mosek.Env.solitem.xx,
                                      /* Which part of solution.  */
                                      0,
                                      /* Index of first variable. */
                                      NUMVAR,
                                      /* Index of last variable+1 */
                                      xx);

                for(int j = 0; j < NUMVAR; ++j)
                    System.out.println ("x[" + j + "]:" + xx[j]);                             
            }
        catch (mosek.ArrayLengthException e)
            {
                System.out.println ("Error: An array was too short");
                System.out.println (e.toString ());
            }
        catch (mosek.Exception e)
            /* Catch both Error and Warning */
            {
                System.out.println ("An error was encountered");
                System.out.println (e.getMessage ());
            }

        if (task != null) task.dispose ();
        if (env  != null)  env.dispose ();
    }
}
