##
#   Copyright: Copyright (c) 1998-2007 MOSEK ApS, Denmark. All rights reserved.
#
#   File:    lo1.py
#
#   Purpose: Demonstrates how to solve small linear
#            optimization problem using the MOSEK Python API.
#
##

import sys
import os

import pymosek as mosek

try:
    from Numeric import array, Float, zeros, ones
except ImportError:
    from mosekarr import array, Float, zeros, ones

# Since the actual value of Infinity is ignores, we define it solely
# for symbolic purposes:
inf = 0.0


# Define a stream printer to grab output from MOSEK
def streamprinter(text):
    sys.stdout.write(text)
    sys.stdout.flush()

# We might write everything directly as a script, but it looks nicer
# to create a function.
def main ():
    # Open MOSEK and create an environment and task
    # Create a handle to MOSEK
    mskhandle = mosek.mosek ()
    # Make a MOSEK environment
    env = mskhandle.Env ()
    # Attach a printer to the environment
##REF:enum:streamtype:log
    env.set_Stream (mosek.streamtype.log, streamprinter)
    # Initialize the environment
##REF:func:env:initenv
    env.init ()

    # Create a task
    task = env.Task(0,0)
    # Attach a printer to the task
    task.set_Stream (mosek.streamtype.log, streamprinter)
    

    # Bound keys for constraints
    bkc = array ([mosek.boundkey.fx,
                  mosek.boundkey.lo,
                  mosek.boundkey.up])
    # Bound values for constraints
    blc = array ([30.0, 15.0, -inf])
    buc = array ([30.0, +inf, 25.0])
    
    # Bound keys for variables
    bkx = array ([mosek.boundkey.lo,
                  mosek.boundkey.ra,
                  mosek.boundkey.lo,
                  mosek.boundkey.lo])
    # Bound values for variables
    blx = array ([ 0.0,  0.0,  0.0,  0.0])
    bux = array ([+inf, 10.0, +inf, +inf])

    # Objective coefficients
    c = array([ 3.0, 1.0, 5.0, 1.0 ])

    # We input the A matrix column-wise
    # asub contains row indexes
    asub = array([ 0, 1,
                   0, 1, 2,
                   0, 1,
                      1, 2])
    # acof contains coefficients
    acof = array([ 3.0, 2.0,
                   1.0, 1.0, 2.0,
                   2.0, 3.0,
                        1.0, 3.0 ])
    # aptrb and aptre contains the offsets into asub and acof where
    # columns start and end respectively
    aptrb = array([ 0, 2, 5, 7 ])
    aptre = array([ 2, 5, 7, 9 ])

    numvar = len(bkx)
    numcon = len(bkc)

##REF:func:task:inputdata
    # Load data into task
    print 'ptrb =',aptrb
    print 'ptre =',aptre
    print "numvar =",numvar
    print "numcon =",numcon
    task.inputdata (numcon,numvar,
                    c, # linear objective coefficients
                    0.0, # objective fixed value
                    aptrb,
                    aptre,
                    asub,acof,
                    bkc,blc,buc,
                    bkx,blx,bux)
##REF:func:task:putintparam
##REF:param:iparam:objective_sense
    task.putobjsense(mosek.objsense.maximize)
    
##REF:func:task:optimize
    task.optimize ()
    print "Solution summary"

##REF:func:task:solutionsummary
##REF:enum:streamtype:msg
    task.solutionsummary (mosek.streamtype.msg);

    xx = zeros(numvar, Float)
    print "point 13"
##REF:func:task:getsolutionslice
##REF:enum:soltype:itr
##REF:enum:solitem:xx
    task.getsolutionslice(mosek.soltype.bas,
                          mosek.solitem.xx,
                          0, numvar,
                          xx)
    print "point 14"
    print "x =", xx



# call the main function
try:
    main ()
except mosek.Exception, e:
    print "ERROR: %s" % str(e.errno)
    if e.msg is not None:
        print "\t%s" % e.msg
    sys.exit(1)
except:
    import traceback
    traceback.print_exc()
    sys.exit(1)
