echo "*** Testing MOSEK optimization tools."

MSKPLATFORM=$1
shift

echo "Platform            : $MSKPLATFORM."

MSKDIR=$MSKPLATFORM

PWD=`pwd`

MOSEKINC=./platform/$MSKDIR/h
MOSEKBIN=./platform/$MSKDIR/bin
MOSEKLIB=./platform/$MSKDIR/lib
MOSEKJAR=./platform/$MSKDIR/bin
LDIR=$PWD/platform/$MSKDIR/bin

JAVAAPI=0
CC=""  

while [ $# -ne 0 ]
do
    case $1 in
        javaapi)
            JAVAAPI=1 
            ;;
        -cc)
            shift
            CC=$1
            ;;
        *)
            echo Unknown option: $1
    esac
    shift
done

echo "Testing the JAVA API: $JAVAAPI"

MSKJAVA="java"
case $MSKPLATFORM in
  aixrs6k)
    MSKCC=xlc_r
    MSKLINKFLAGS="-brtl -ldl -lm" 
    ;;    

  aixrs6k64)
    MSKCC="xlc_r -q64"
    MSKLINKFLAGS="-brtl -ldl -lm" 
    ;; 

  hpuxpa32)
    MSKCC="cc +DD32 +DAportable"
    MSKLINKFLAGS="-lpthread -lc -lm -Wl,+s" 
    ;;    

  hpuxpa64)
    MSKCC="cc +DD64 +DA2.0W +DS2.0W"
    MSKLINKFLAGS="-lpthread -lc -lm" 
    ;;

  linux32x86)
    MSKCC="gcc"
    MSKLINKFLAGS="-lpthread -lc -ldl -lm" 
    ;; 

  linux64x86)
    MSKCC="gcc -m64"
    MSKLINKFLAGS="-lpthread -lc -ldl -lm" 
    ;;

  linuxia64)
    MSKCC="gcc"
    MSKLINKFLAGS="-lpthread -lc -ldl -lm" 
    ;;

  linuxintel)
    MSKCC="gcc"
    MSKLINKFLAGS="-lpthread -lc -ldl -lm" 
    ;;     

  osx32ppc)
    MSKCC="gcc"
    MSKLINKFLAGS="-lpthread -lSystem -lm" 
    ;;     

  osx32x86)
    MSKCC="gcc"
    MSKLINKFLAGS="-lguide -lirc -limf -lpthread -lSystem -lm -Xlinker -bind_at_load" 
    ;;     

 solaris32x86 )
    MSKCC="cc"
    MSKLINKFLAGS="-lsocket -lnsl -lintl -lthread -lpthread -lc -ldl -lm"
    ;;

 solaris64x86 )
    MSKCC="cc -xarch=amd64"
    MSKLINKFLAGS="-lsocket -lnsl -lintl -lthread -lpthread -lc -ldl -lm"
    MSKJAVA="java -d64"
    ;;

  solarissparc )
    MSKCC="cc"
    MSKLINKFLAGS="-lsocket -lnsl -lintl -lthread -lpthread -lc -ldl -lm"
    ;;

  solarissparc64 )
    MSKCC="cc -xtarget=generic64"
    MSKLINKFLAGS="-lsocket -lnsl -lintl -lthread -lpthread -lc -ldl -lm"
    MSKJAVA="java -d64"
    ;;
esac

if [ "$CC" != "" ]; then
    MSKCC=$CC 
fi

echo "C compiler          : $MSKCC"
echo "Link flags          : $MSKLINKFLAGS" 

# Setup license file.
MOSEKLM_LICENSE_FILE=../licenses
export MOSEKLM_LICENSE_FILE 

. $MOSEKBIN/mosekver.sh
MSKVER=MOSEK_VERSION_MAJOR.MOSEK_VERSION_MINOR

LMOSEKLIBS="-L$MOSEKLIB -lmosekbin -lamplsolver -lmosekdl -lsysinfo -lz" 
case $MSKPLATFORM in
  aixrs6k)
    DLL_EXT=.so
    LIBMOSEK="-L$LDIR -L$MOSEKLIB -lmosek -brtl"
    LIBPATH=$LDIR:$LIBPATH
    export LIBPATH
    ;;    

  aixrs6k64)
    DLL_EXT=64.so
    LIBMOSEK="-L$LDIR -L$MOSEKLIB -lmosek64 -brtl"
    LIBPATH=$LDIR:$LIBPATH
    export LIBPATH
    ;;    

  hpuxpa32)
    DLL_EXT=.sl
    LIBMOSEK="-L$LDIR -L$MOSEKLIB -lmosek"
    SHLIB_PATH=$LDIR:$SHLIB_PATH
    export SHLIB_PATH

    LD_LIBRARY_PATH=$LDIR:$LD_LIBRARY_PATH
    export LD_LIBRARY_PATH
    ;;    

  hpuxpa64)
    DLL_EXT=64.sl
    LIBMOSEK="-L$LDIR -L$MOSEKLIB -lmosek64"
    LD_LIBRARY_PATH=$LDIR:$LD_LIBRARY_PATH
    export LD_LIBRARY_PATH
    ;;    

  linux32x86)
    DLL_EXT=.so
    LIBMOSEK="-L$LDIR -L$MOSEKLIB -lmosek" 
    LD_LIBRARY_PATH=$LDIR:$LD_LIBRARY_PATH
    export LD_LIBRARY_PATH
    ;;

  linux64x86)
    DLL_EXT=64.so
    LIBMOSEK="-L$LDIR -L$MOSEKLIB -lmosek64"
    LD_LIBRARY_PATH=$LDIR:$LD_LIBRARY_PATH
    export LD_LIBRARY_PATH
    ;;

  linuxia64)
    DLL_EXT=64.so
    LMOSEKLIBS="-L$MOSEKLIB -lmosekbin -lmosekdl -lz" 
    LIBMOSEK="-L$LDIR -L$MOSEKLIB -lmosek64"
    LD_LIBRARY_PATH=$LDIR:$LD_LIBRARY_PATH
    export LD_LIBRARY_PATH
    ;;

  linuxintel)
    DLL_EXT=.so
    LIBMOSEK="-L$LDIR -L$MOSEKLIB -lmosek"
    LD_LIBRARY_PATH=$LDIR:$LD_LIBRARY_PATH
    export LD_LIBRARY_PATH
    ;;

  osx32ppc)
    DLL_EXT=.dylib
    LIBMOSEK="-L$LDIR -L$MOSEKLIB -lmosek"
    DYLD_LIBRARY_PATH=$LDIR:$DYLD_LIBRARY_PATH
    export DYLD_LIBRARY_PATH
    ;;

  osx32x86)
    DLL_EXT=.dylib
    LIBMOSEK="-L$LDIR             -lmosek"
    DYLD_LIBRARY_PATH=$LDIR:$DYLD_LIBRARY_PATH
    export DYLD_LIBRARY_PATH
    ;;

  solaris32x86)
    DLL_EXT=.so
    LIBMOSEK="-L$LDIR -L$MOSEKLIB -lmosek"
    LD_LIBRARY_PATH=$LDIR:$LD_LIBRARY_PATH
    export LD_LIBRARY_PATH
    ;;

  solaris64x86)
    DLL_EXT=64.so
    LIBMOSEK="-L$LDIR -L$MOSEKLIB -lmosek64"
    LD_LIBRARY_PATH=$LDIR:$LD_LIBRARY_PATH
    export LD_LIBRARY_PATH
    ;;
    
  solarissparc)
    DLL_EXT=.so
    LIBMOSEK="-L$LDIR -L$MOSEKLIB -lmosek"
    LD_LIBRARY_PATH=$LDIR:$LD_LIBRARY_PATH
    export LD_LIBRARY_PATH
    ;;   

  solarissparc64)
    DLL_EXT=64.so
    LIBMOSEK="-L$LDIR -L$MOSEKLIB -lmosek64"
    LD_LIBRARY_PATH=$LDIR:$LD_LIBRARY_PATH
    export LD_LIBRARY_PATH
    ;;   

  * )
    DLL_EXT=.so
    LIBMOSEK="-L$LDIR -L$MOSEKLIB -lmosek"
    LD_LIBRARY_PATH=$LDIR:$LD_LIBRARY_PATH
    export LD_LIBRARY_PATH
    ;;
esac

echo "LD_LIBRARY_PATH     : $LD_LIBRARY_PATH"
echo "SHLIB_PATH          : $SHLIB_PATH"
echo "LIBPATH             : $LIBPATH"
echo "DYLD_LIBRARY_PATH   : $DYLD_LIBRARY_PATH"

printf '\n*** Testing linear optimizer. This problem may not be solvable due to license.\n'
printf "*** Testing: interior point\n"
$MOSEKBIN/mosek -f examples/data/25fv47.mps -d MSK_IPAR_OPTIMIZER MSK_OPTIMIZER_INTPNT

printf "\n\n*** Testing: primal simplex\n"
$MOSEKBIN/mosek -f examples/data/25fv47.mps -d MSK_IPAR_OPTIMIZER MSK_OPTIMIZER_PRIMAL_SIMPLEX
printf 'done\n\n'

printf 'Testing mixed integer optimizer\n'
$MOSEKBIN/mosek ./examples/data/flugpl.mps
printf 'done\n\n'

LCC="$MSKCC -I $MOSEKINC"

printf '*** Testing: lo1\n'
printf '    $LCC -o lo1      ./examp/lo1.c          $LIBMOSEK $MSKLINKFLAGS\n'
$LCC -o lo1      ./examples/c/lo1.c          $LIBMOSEK $MSKLINKFLAGS
./lo1 
printf 'done\n\n'

printf '*** Testing: qo1\n'
$LCC -o qo1      ./examples/c/qo1.c          $LIBMOSEK $MSKLINKFLAGS
./qo1 
printf 'done\n\n'

printf '*** Building dgopt\n'
$LCC -o rundgopt ./examples/c/mskdgopt.c  ./examples/c/dgopt.c          $LIBMOSEK $MSKLINKFLAGS
./rundgopt examples/data/dgo.mps examples/data/dgo.f
printf 'done\n\n'

printf '*** Building mskscopt\n'
$LCC -c -o ./scopt.o  -I examples/c examples/c/scopt.c
$LCC    -o ./mskscopt -I examples/c examples/c/mskscopt.c ./scopt.o $LIBMOSEK  $MSKLINKFLAGS
printf 'done\n\n'

printf "*** Testing: callback\n"
$LCC -o callback ./examples/c/callback.c     $LIBMOSEK $MSKLINKFLAGS
./callback examples/data/25fv47.mps
printf "done\n\n"

if [ $JAVAAPI -eq 1 ]; then

printf '*** Testing Java\n'

printf "Compiling java examples:\n"

mkdir -p tmp/java

javac -d tmp/java -classpath $MOSEKJAR/mosek.jar \
    examples/java/lo1.java \
    examples/java/lo2.java \
    examples/java/qo1.java \
    examples/java/cqo1.java \
    examples/java/qcqo1.java 

printf "Running java examples:\n"
java  -version

for f in  "lo1" "lo2" "qo1" "cqo1" "qcqo1" ; do
    printf "\nRunning java example: $f.$f\n"
    printf "Current directory: $PWD\n"
    printf "With command line: $MSKJAVA  -classpath $MOSEKJAR/mosek.jar:tmp/java $f.$f\n"
    $MSKJAVA  -classpath $MOSEKJAR/mosek.jar:tmp/java $f.$f
done

printf 'done with java examples\n\n'

fi

printf '*** Checking FLEXlm version\n\n'
printf ' lmgrd: \n'
$MOSEKBIN/lmutil lmver $MOSEKBIN/lmgrd 
printf '\n'

printf ' libmosek: \n'
$MOSEKBIN/lmutil lmver platform/$MSKPLATFORM/bin/libmosek$DLL_EXT
printf 'done\n\n'

$MOSEKBIN/mosek -f
